@@ -22,22 +22,24 @@ use App::YTDL::GetData      qw( get_vimeo_list_info get_download_info get_youtub
 sub from_arguments_to_choices {
     my ( $opt, @ids ) = @_;
     my $info = {};
-    my $invalid_char = $opt->{invalid_char};
-    my $more = 0;
     for my $webpage_url ( @ids ) {
-        if ( $webpage_url =~ /^c#([\p{PerlWord}-]+)\z/ ) {
+        if ( $webpage_url =~ /^u#([\p{PerlWord}-]+)\z/ ) {
             $webpage_url = sprintf 'https://www.youtube.com/user/%s/', $1;
         }
-        if ( $webpage_url =~ /^p#(?:[FP]L)?([\p{PerlWord}-]+)\z/ ) {
+        elsif ( $webpage_url =~ /^c#([\p{PerlWord}-]+)\z/ ) {
+            $webpage_url = sprintf 'https://www.youtube.com/channel/%s/', $1;
+        }
+        elsif ( $webpage_url =~ /^p#(?:[FP]L)?([\p{PerlWord}-]+)\z/ ) {
             $webpage_url = sprintf 'https://www.youtube.com/playlist?list=%s/', $1;
         }
-        if ( my $user_id = _youtube_user_id( $opt, $webpage_url ) ) {
+        if ( my $video_id = _youtube_video_id( $opt, $webpage_url ) ) {
             my $ex = 'youtube';
-            my $tmp = _youtube_list_info( $opt, 'User', $user_id );
-            next if ! defined $tmp;
-            my ( $vi ) = keys %{$tmp->{$ex}};
-            my $prompt = $tmp->{$ex}{$vi}{uploader};
-            choose_videos( $opt, $info, $tmp, $ex, $prompt );
+            $info->{$ex}{$video_id}{extractor}   = $ex;
+            $info->{$ex}{$video_id}{webpage_url} = sprintf 'https://www.youtube.com/watch?v=%s', $video_id;
+            prepare_info( $opt, $info, $ex, $video_id );
+        }
+        elsif ( my $playlist_id = _youtube_playlist_id( $opt, $webpage_url ) ) {
+            _generic( $opt, $info, $webpage_url );
         }
         elsif ( my $channel_id = _youtube_channel_id( $opt, $webpage_url ) ) {
             my $ex = 'youtube';
@@ -47,11 +49,13 @@ sub from_arguments_to_choices {
             my $prompt = $tmp->{$ex}{$vi}{uploader};
             choose_videos( $opt, $info, $tmp, $ex, $prompt );
         }
-        elsif ( my $video_id = _youtube_video_id( $opt, $webpage_url )  ) {
+        elsif ( my $user_id = _youtube_user_id( $opt, $webpage_url ) ) {
             my $ex = 'youtube';
-            $info->{$ex}{$video_id}{extractor}   = 'youtube';
-            $info->{$ex}{$video_id}{webpage_url} = sprintf 'https://www.youtube.com/watch?v=%s', $video_id;
-            prepare_info( $opt, $info, $ex, $video_id );
+            my $tmp = _youtube_list_info( $opt, 'User', $user_id );
+            next if ! defined $tmp;
+            my ( $vi ) = keys %{$tmp->{$ex}};
+            my $prompt = $tmp->{$ex}{$vi}{uploader};
+            choose_videos( $opt, $info, $tmp, $ex, $prompt );
         }
         elsif ( my $vimeo_uploader_id = _vimeo_uploader_id( $opt, $webpage_url )  ) {
             my $ex = 'vimeo';
@@ -71,7 +75,7 @@ sub from_arguments_to_choices {
 
 sub _generic {
     my ( $opt, $info, $webpage_url ) = @_;
-    my $message = "Fetching download info: ";
+    my $message = "** GET download info: ";
     my $tmp = get_download_info( $opt, $webpage_url, $message );
     return if ! defined $tmp;
     my ( $ex ) = keys %$tmp;
@@ -89,37 +93,96 @@ sub _generic {
 
 sub _youtube_video_id {
     my ( $opt, $webpage_url ) = @_;
-    my $invalid_char = $opt->{invalid_char};
-    return     if ! $opt->{fast_list_youtube};
-    return     if ! $webpage_url;
-    return $1  if   $webpage_url =~ m{^([\p{PerlWord}-]{11})\z};
-    return     if   $webpage_url !~ $opt->{yt_regexp};
-    return $1  if   $webpage_url =~ m{/.*?[?&;!](?:v|video_id)=([^$invalid_char]+)};
-    return $1  if   $webpage_url =~ m{/(?:e|v|embed)/([^$invalid_char]+)};
-    return $1  if   $webpage_url =~ m{#p/(?:u|search)/\d+/([^&?/]+)};
-    return $1  if   $webpage_url =~ m{youtu.be/([^$invalid_char]+)};
+    return if ! $opt->{fast_list_youtube};
+    return if ! $webpage_url;
+    return if   $webpage_url =~ m|http://|;
+    my $regexp_video_url = qr"          # youtube-dl/youtube_dl/extractor/youtube.py    2015.07.21
+        ^
+        (
+            (?:https?://|//)                                    # http(s):// or protocol-independent URL
+            (?:(?:(?:(?:\w+\.)?[yY][oO][uU][tT][uU][bB][eE](?:-nocookie)?\.com/|
+            (?:www\.)?deturl\.com/www\.youtube\.com/|
+            (?:www\.)?pwnyoutube\.com/|
+            (?:www\.)?yourepeat\.com/|
+            tube\.majestyc\.net/|
+            youtube\.googleapis\.com/)                           # the various hostnames, with wildcard subdomains
+            (?:.*?\#/)?                                          # handle anchor (#/) redirect urls
+            (?:                                                  # the various things that can precede the ID:
+                (?:(?:v|embed|e)/(?!videoseries))                # v/ or embed/ or e/
+                |(?:                                             # or the v= param in all its forms
+                    (?:(?:watch|movie)(?:_popup)?(?:\.php)?/?)?  # preceding watch(_popup|.php) or nothing (like /?v=xxxx)
+                    (?:\?|\#!?)                                  # the params delimiter ? or # or #!
+                    (?:.*?&)?                                    # any other preceding param (like /?s=tuff&v=xxxx)
+                    v=
+                )
+            ))
+            |youtu\.be/                                          # just youtu.be/xxxx
+            |(?:www\.)?cleanvideosearch\.com/media/action/yt/watch\?videoId=
+            )
+        )?                                                       # all until now is optional -> you can pass the naked ID
+        ([0-9A-Za-z_-]{11})                                      # here is it! the YouTube video ID
+        (?!.*?&list=)                                            # combined list/video URLs are handled by the playlist IE
+        (?(1).+)?                                                # if we found the ID, everything can follow
+        $
+    "x;
+    return $2 if $webpage_url =~ $regexp_video_url; # $2
     return;
 }
 
 
-sub _youtube_user_id {
+sub _youtube_playlist_id {
     my ( $opt, $webpage_url ) = @_;
-    my $invalid_char = $opt->{invalid_char};
-    return    if ! $opt->{fast_list_youtube};
-    return    if ! $webpage_url;
-    return    if   $webpage_url !~ $opt->{yt_regexp};
-    return $1 if   $webpage_url =~ m{/user/([^$invalid_char]+)};
+    return if ! $opt->{fast_list_youtube};
+    return if ! $webpage_url;
+    return if   $webpage_url =~ m|http://|;
+    my $regexp_playlist_url = qr"           # youtube-dl/youtube_dl/extractor/youtube.py    2015.07.21
+        (?:
+        (?:https?://)?
+        (?:\w+\.)?
+        youtube\.com/
+        (?:
+            (?:course|view_play_list|my_playlists|artist|playlist|watch|embed/videoseries)
+            \? (?:.*?&)*? (?:p|a|list)=
+        |  p/
+        )
+        (
+            (?:PL|LL|EC|UU|FL|RD|UL)?[0-9A-Za-z-_]{10,}
+            # Top tracks, they can also include dots
+            |(?:MC)[\w\.]*
+        )
+        .*
+        |
+        ((?:PL|LL|EC|UU|FL|RD|UL)[0-9A-Za-z-_]{10,})
+        )
+
+    "x;
+    return $1 if $webpage_url =~ $regexp_playlist_url; # $1
     return;
 }
 
 
 sub _youtube_channel_id {
     my ( $opt, $webpage_url ) = @_;
-    my $invalid_char = $opt->{invalid_char};
-    return    if ! $opt->{fast_list_youtube};
-    return    if ! $webpage_url;
-    return    if   $webpage_url !~ $opt->{yt_regexp};
-    return $1 if   $webpage_url =~ m{/channel/([^$invalid_char]+)};
+    return if ! $opt->{fast_list_youtube};
+    return if ! $webpage_url;
+    return if   $webpage_url =~ m|http://|;
+    my $regexp_channel_url = qr"            # youtube-dl/youtube_dl/extractor/youtube.py    2015.07.21
+        https?://(?:youtu\.be|(?:\w+\.)?youtube(?:-nocookie)?\.com)/channel/(?P<id>[0-9A-Za-z_-]+)
+    "x;
+    return $+{id} if $webpage_url =~ $regexp_channel_url; # $+{id}
+    return;
+}
+
+
+sub _youtube_user_id {
+    my ( $opt, $webpage_url ) = @_;
+    return if ! $opt->{fast_list_youtube};
+    return if ! $webpage_url;
+    return if   $webpage_url =~ m|http://|;
+    my $regexp_user_url = qr"           # youtube-dl/youtube_dl/extractor/youtube.py    2015.07.21
+        (?:(?:(?:https?://)?(?:\w+\.)?youtube\.com/(?:user/)?(?!(?:attribution_link|watch|results)(?:$|[^a-z_A-Z0-9-])))|ytuser:)(?!feed/)(?P<id>[A-Za-z0-9_-]+)
+    "x;
+    return $+{id} if $webpage_url =~ $regexp_user_url; # $+{id}
     return;
 }
 
