@@ -67,7 +67,7 @@ sub prepare_info {
     $info->{$ex}{$video_id}{title}           ||= sprintf 'no_title_%s', $video_id;
     $info->{$ex}{$video_id}{duration}        ||= '-:--:--';
     $info->{$ex}{$video_id}{upload_date}     ||= '';
-    $info->{$ex}{$video_id}{upload_datetime} ||= '0000-00-00T00:00:00';
+    $info->{$ex}{$video_id}{upload_datetime} ||= $opt->{no_upload_datetime}; # '0000-00-00T00:00:00';
     $info->{$ex}{$video_id}{playlist_id} //= '';
     $info->{$ex}{$video_id}{uploader_id} //= $info->{$ex}{$video_id}{uploader} // '';
     $info->{$ex}{$video_id}{uploader}    //= $info->{$ex}{$video_id}{uploader_id};
