@@ -14,13 +14,12 @@ use Fcntl              qw( LOCK_EX LOCK_SH SEEK_END );
 use Time::Local        qw( timelocal );
 use Unicode::Normalize qw( NFC );
 
-use Encode::Locale      qw();
-use File::Touch         qw();
-use IPC::System::Simple qw( capture system );
-use JSON                qw();
-use Term::Choose::Util  qw( unicode_trim );
-#use Text::Unidecode     qw( unidecode ); # require-d
-use Unicode::GCString   qw();
+use Encode::Locale         qw();
+use File::Touch            qw();
+use IPC::System::Simple    qw( capture system );
+use JSON                   qw();
+use Term::Choose::LineFold qw( print_columns cut_to_printwidth);
+#use Text::Unidecode       qw( unidecode ); # require-d
 
 use if $^O eq 'MSWin32', 'Win32::ShellQuote';
 
@@ -36,10 +35,10 @@ sub get_filename {
     $ext //= 'unknown';
     $fmt //= '';
     $fmt = '_' . $fmt if length $fmt;
-    my $len_ext = Unicode::GCString->new( $ext )->columns();
-    my $len_fmt = Unicode::GCString->new( $fmt )->columns();
+    my $len_ext = print_columns( $ext );
+    my $len_fmt = print_columns( $fmt );
     my $max_len_title = $opt->{max_len_f_name} - ( $len_fmt + 1 + $len_ext );
-    $title = unicode_trim( sanitize_for_path( $opt, $title ), $max_len_title );
+    $title = cut_to_printwidth( sanitize_for_path( $opt, $title ), $max_len_title );
     my $file_name = $title . $fmt . '.' . $ext;
     return $file_name;
 }
